package com.adc.da.util;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Component;

import java.io.File;
import java.net.URLEncoder;
import java.util.ArrayList;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;

/**
 * 百度iocr识别
 *
 * @author David
 */
@Component
public class BaiduIOCRUtils {

    private static final Logger logger = LoggerFactory.getLogger(BaiduIOCRUtils.class);

    /**
     * 百度orc识别方法
     *
     * @param file
     * @param templateSign
     * @return
     */
    public Map<String, String> orc(File file, String templateSign) {
        String recogniseUrl = "https://aip.baidubce.com/rest/2.0/solution/v1/iocr/recognise";

        try {
            byte[] imgData = FileUtil.readFileByBytes(file);
            String imgStr = Base64Util.encode(imgData);
            // 请求模板参数
            String recogniseParams = String.format("templateSign=%s&image=%s", templateSign, URLEncoder.encode(imgStr, "UTF-8"));
            String accessToken = BaiduAuthService.getAuth();
            // 请求模板识别
            String result = HttpUtil.post(recogniseUrl, accessToken, recogniseParams);
            JSONObject jsonObject = JSONObject.parseObject(result);
            int error_code = jsonObject.getIntValue("error_code");
            LinkedHashMap<String, String> orcMap = new LinkedHashMap<>();
            if (error_code == 0) {
                JSONArray array = jsonObject.getJSONObject("data").getJSONArray("ret");
                for (Object item : array) {
                    Map<String, String> map = (Map<String, String>) item;
                    orcMap.put(map.get("word_name"), map.get("word"));
                }
                return orcMap;
            } else {
                return null;
            }

        } catch (Exception e) {
            logger.error("图片识别失败");
            return null;
        }
    }

    /**
     * orc请求
     *
     * @param file
     * @return
     */
    public Map<String, String> orcAccurate(File file) {
        // 高精度识别apiUrl
        String recogniseUrl = "https://aip.baidubce.com/rest/2.0/ocr/v1/accurate_basic";

//        String filePath = "C:\\Users\\26635\\Desktop\\长城汽车生产一致性管理系统\\ECU1.png";
        try {
            byte[] imgData = FileUtil.readFileByBytes(file);
            String imgStr = Base64Util.encode(imgData);
            // 请求分类器参数
            String classifierParams = "classifierId=your_classfier_id&image=" + URLEncoder.encode(imgStr, "UTF-8");

            String accessToken = BaiduAuthService.getAuth();
            // 请求分类器识别
            String result = HttpUtil.post(recogniseUrl, accessToken, classifierParams);
            JSONObject jsonObject = JSONObject.parseObject(result);
            int error_code = jsonObject.getIntValue("error_code");
            LinkedHashMap<String, String> orcMap = new LinkedHashMap<>();
            if (error_code == 0) {
                String regex = "^[^A-Z0-9\\-\\#]+$";
                JSONArray array = jsonObject.getJSONArray("words_result");
                for (Object item : array) {
                    Map<String, String> map = (Map<String, String>) item;
                    if (!map.get("words").matches(regex)) {
                        if (StringUtils.isEmpty(orcMap.get("num"))) {
                            orcMap.put("num", map.get("words"));
                        } else {
                            orcMap.put("num", orcMap.get("num") + map.get("words"));
                        }

                    }
                }
            }
            return orcMap;
        } catch (Exception e) {
            logger.error("图片识别失败");
            return null;
        }
    }

    /**
     * orc请求
     *
     * @param file
     * @return
     */
    public String orcENV(File file, String certificateType) {
        // 高精度识别apiUrl
        String recogniseUrl = "https://aip.baidubce.com/rest/2.0/ocr/v1/accurate_basic";
        List<String> list = new ArrayList<>();
        //list.add("11");
        list.add("12");
        //list.add("14");
        //list.add("15");
        list.add("16");
        //list.add("18");
        list.add("19");
        if (list.contains(certificateType)) {
            try {
                byte[] imgData = FileUtil.readFileByBytes(file);
                String imgStr = Base64Util.encode(imgData);
                // 请求分类器参数
                String classifierParams = "classifierId=your_classfier_id&image=" + URLEncoder.encode(imgStr, "UTF-8");

                String accessToken = BaiduAuthService.getAuth();
                // 请求分类器识别
                String result = HttpUtil.post(recogniseUrl, accessToken, classifierParams);
                JSONObject jsonObject = JSONObject.parseObject(result);
                int error_code = jsonObject.getIntValue("error_code");
                LinkedHashMap<String, String> orcMap = new LinkedHashMap<>();
                if (error_code == 0) {
                    JSONArray array = jsonObject.getJSONArray("words_result");
                    for (Object item : array) {
                        Map<String, String> map = (Map<String, String>) item;

                        orcMap.put(String.valueOf(orcMap.size()), map.get("words"));
                    }
                    //if("13".equals(certificateType) || "17".equals(certificateType) || "19".equals(certificateType)){
                    String str = orcMap.get("0") + orcMap.get("1") + orcMap.get("2") + orcMap.get("3") + orcMap.get("4") + orcMap.get("5");
                    return str.substring(str.indexOf("本企业承诺"));
                    //}
                    //return orcMap.get("2")+orcMap.get("3")+orcMap.get("4")+orcMap.get("5")+orcMap.get("6");
                }
                return "";
            } catch (Exception e) {
                logger.error("图片识别失败");
                return "";
            }
        } else {
            return "";
        }
    }

    public static void main(String[] args) throws Exception {
        // iocr识别apiUrl
        String recogniseUrl = "https://aip.baidubce.com/rest/2.0/ocr/v1/accurate_basic";

        String filePath = "C:\\Users\\26635\\Desktop\\汽油发动机2.jpg";
        try {
            byte[] imgData = FileUtil.readFileByBytes(filePath);
            String imgStr = Base64Util.encode(imgData);
            // String templateSign =  "3385a3e06c135394d3454d3e7f6d9f4a";
            // 请求模板参数
            // String recogniseParams = "templateSign=" + templateSign + "&image=" + URLEncoder.encode(imgStr, "UTF-8");
            // 请求分类器参数
            String classifierParams = "classifierId=your_classfier_id&image=" + URLEncoder.encode(imgStr, "UTF-8");

            String accessToken = BaiduAuthService.getAuth();
            // 请求模板识别
//            String result = HttpUtil.post(recogniseUrl, accessToken, recogniseParams);
            // 请求分类器识别
            String result = HttpUtil.post(recogniseUrl, accessToken, classifierParams);
            JSONObject jsonObject = JSONObject.parseObject(result);
            int error_code = jsonObject.getIntValue("error_code");
            Map<String, String> orcMap = new LinkedHashMap<>();
            if (error_code == 0) {
                String regex = "^[^A-Z0-9\\-\\#]+$";
                JSONArray array = jsonObject.getJSONArray("words_result");
                for (Object item : array) {
                    Map<String, String> map = (Map<String, String>) item;
                    logger.debug(map.get("words"));
                    if (!map.get("words").matches(regex)) {
                        if (StringUtils.isEmpty(orcMap.get("num"))) {
                            orcMap.put("num", map.get("words"));
                        } else {
                            orcMap.put("num", orcMap.get("num") + map.get("words"));
                        }

                    }
                }
                logger.debug(orcMap.toString());
            }
        } catch (Exception e) {
            logger.error("图片识别失败");
        }
    }

}
