package com.adc.da.util;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.beans.BeanInfo;
import java.beans.IntrospectionException;
import java.beans.Introspector;
import java.beans.PropertyDescriptor;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.Map;

/**
 * //功能描述： 添加类/接口功能描述
 *
 * @author 周梓武
 * @date 2019-09-25
 */
public class BeanUtils {
    private static final Logger logger = LoggerFactory.getLogger(BeanUtils.class);

    /**
     * 私有构造方法
     */
    private BeanUtils() {
    }

    /**
     * map转为bean
     * @param mp map
     * @param beanCls bean
     * @param <T> bean的类型
     * @param <K> map key的类型
     * @param <V> map value的类型
     * @return
     * @throws IllegalArgumentException
     * @throws InvocationTargetException
     */
    public static <T, K, V> T map2Bean(Map<K, V> mp, Class<T> beanCls)
            throws IllegalArgumentException, InvocationTargetException {
        T t = null;
        try {
            BeanInfo beanInfo = Introspector.getBeanInfo(beanCls);
            PropertyDescriptor[] propertyDescriptors = beanInfo.getPropertyDescriptors();
            t = beanCls.newInstance();

            // 遍历属性
            for (PropertyDescriptor property : propertyDescriptors) {
                String key = property.getName();

                if (mp.containsKey(key)) {
                    Object value = mp.get(key);
                    // Java中提供了用来访问某个属性的
                    Method setter = property.getWriteMethod();
                    // getter/setter方法
                    setter.invoke(t, value);
                }
            }

        } catch (IntrospectionException | IllegalAccessException | InstantiationException e) {

            logger.error("转换错误");
        }
        return t;
    }
}
