package com.adc.da.util;

import org.apache.commons.lang3.StringUtils;
import org.apache.poi.hssf.usermodel.HSSFCell;
import org.apache.poi.hssf.usermodel.HSSFClientAnchor;
import org.apache.poi.hssf.usermodel.HSSFPatriarch;
import org.apache.poi.hssf.usermodel.HSSFRow;
import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.openxml4j.exceptions.InvalidFormatException;
import org.apache.poi.poifs.filesystem.POIFSFileSystem;
import org.apache.poi.ss.usermodel.CellType;
import org.apache.poi.xssf.usermodel.XSSFCell;
import org.apache.poi.xssf.usermodel.XSSFRow;
import org.apache.poi.xssf.usermodel.XSSFSheet;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;

import javax.imageio.ImageIO;
import javax.servlet.http.HttpServletRequest;
import java.awt.image.BufferedImage;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLEncoder;
import java.util.ArrayList;
import java.util.List;


/**
 * 刘慧文
 *
 * @author LLFY
 */
public class ExcelUtil {

    private ExcelUtil() {

    }

    private static String JPG = "jpg";
    private static String EDGE = "Edge";
    private static String CHROME = "Chrome";
    private static String FIREFOX = "Firefox";
    private static String USERAGENT = "USER-AGENT";
    private static String UTF8 = "UTF8";
    private static String ISO88591 = "ISO8859-1";

    public static void setPicture(HSSFSheet sheet, HSSFPatriarch patriarch, HSSFWorkbook wb, String uploadFile, String path, String value, int rowNum, int cellNum) {
        BufferedImage bufferImg;
        try {
            ByteArrayOutputStream byteArrayOut = new ByteArrayOutputStream();
            bufferImg = ImageIO.read(new File(uploadFile + path));
            ImageIO.write(bufferImg, JPG, byteArrayOut);
            //anchor主要用于设置图片的属性
            HSSFClientAnchor anchor = new HSSFClientAnchor(!value.isEmpty() ? 512 : 0, 0, 0, 255, (short) cellNum, rowNum, (short) ((short) cellNum + 1), rowNum);
            sheet.getRow(rowNum).setHeight((short) 1000);
            anchor.setAnchorType(3);
            //插入图片
            patriarch.createPicture(anchor, wb.addPicture(byteArrayOut.toByteArray(), HSSFWorkbook.PICTURE_TYPE_JPEG));
        } catch (Exception e) {
//            throw new AdcDaBaseException("下载文件失败，请重试");
        }
    }

    public static String isUserAgent(String fileName, HttpServletRequest request) throws UnsupportedEncodingException {
        String userAgent = request.getHeader(USERAGENT);
        if (userAgent.contains(EDGE)) {
            //其他浏览器
            fileName = URLEncoder.encode(fileName, UTF8);
            //google,火狐浏览器
        } else if (userAgent.contains(CHROME) || userAgent.contains(FIREFOX)) {
            fileName = new String((fileName).getBytes(), ISO88591);
        } else {
            //其他浏览器
            fileName = URLEncoder.encode(fileName, UTF8);
        }
        return fileName;
    }

    // 读取EXCEL 为List<List<String>>
//    private static  XSSFSheet xssfSheet;
//    private static  XSSFRow xssfRow;
//    private static  XSSFRow headerXssfRow;
//    private static  HSSFRow headerHssfRow;
//    private static  HSSFSheet hssfSheet;
//    private static  HSSFRow hssfRow;
    private static  List<List<String>> datas;
    public static  List<String> data;

    public static  List<List<String>> read(File file) throws IOException, InvalidFormatException {
        String fileName = file.getName();
        if (fileName.substring(fileName.indexOf(".") + 1).equals("xlsx")) {
            return readXSSF(file,0);
        } else if (fileName.substring(fileName.indexOf(".") + 1).equals("xls")) {
            return readHSSF(file);
        }
        return null;
    }

    /**
     * 读取EXCEL2007以上版本
     *
     * @param file excel文件
     * @return
     * @throws IOException
     */
    private static List<List<String>> readXSSF(File file, int sheet) throws IOException, InvalidFormatException {

        datas = new ArrayList<>();

        // 创建HSSFWorkbook对象
        XSSFWorkbook wb = new XSSFWorkbook(file);

       XSSFSheet xssfSheet = wb.getSheetAt(sheet);
        //获取sheet中一共有多少行，遍历行（注意第一行是标题）
        int physicalNumberOfRows = xssfSheet.getPhysicalNumberOfRows();
        int physicalNumberOfCells;
       XSSFRow headerXssfRow = xssfSheet.getRow(0);
        for (int j = 0; j < physicalNumberOfRows; j++) {
            //获取每一行有多少单元格，遍历单元格
            XSSFRow xssfRow = xssfSheet.getRow(j);
            physicalNumberOfCells = headerXssfRow.getPhysicalNumberOfCells();
            data = new ArrayList<>();
            for (int k = 0; k < physicalNumberOfCells; k++) {
                XSSFCell cell = xssfRow.getCell(k);
                if(cell != null){
                    switch (cell.getCellTypeEnum()) {
                        case STRING:
                            data.add(cell.getStringCellValue());
                            break;
                        case BOOLEAN:
                            data.add(String.valueOf(cell.getBooleanCellValue()));
                            break;
                        case NUMERIC:
                            String str = String.valueOf(cell.getNumericCellValue());
                            if (str.contains(".")) {
                                String s = str.substring(str.indexOf(".") +1,str.length());
                                if (StringUtils.isBlank(s.replace("0",""))) {
                                    str = str.substring(0,str.indexOf("."));
                                }
                            }
                            data.add(str);
                            break;
                        case FORMULA:
                            data.add(String.valueOf(cell.getCellFormula()));
                            break;
                        case ERROR:
                            data.add(String.valueOf(cell.getErrorCellString()));
                            break;
                        case BLANK:
                            data.add(String.valueOf(cell.getStringCellValue()));
                            break;
                        case _NONE:
                            data.add(String.valueOf(cell.getStringCellValue()));
                            break;
                        default:
                            data.add("");
                            break;
                    }
//                    if (StringUtils.isBlank(cell.getStringCellValue())) {
                        cell.setCellType(CellType.STRING);
//                    }

                }else{
                    data.add("");
                }

            }
            datas.add(data);
        }
        wb.close();
        return datas;
    }

    /**
     * 读取EXCEL2003以下版本
     *
     * @param file Excel文件
     * @return
     * @throws IOException
     */
    private static List<List<String>> readHSSF(File file) throws IOException {
        datas = new ArrayList<>();
        // 创建HSSFWorkbook对象
        HSSFWorkbook wb = new HSSFWorkbook(new POIFSFileSystem(new FileInputStream(file)));
        //获取一共有多少sheet，然后遍历
        int numberOfSheets = wb.getNumberOfSheets();
        for (int i = 0; i < numberOfSheets; i++) {
           HSSFSheet hssfSheet = wb.getSheetAt(i);
            //获取sheet中一共有多少行，遍历行（注意第一行是标题）
            int physicalNumberOfRows = hssfSheet.getPhysicalNumberOfRows();
            int physicalNumberOfCells;
            for (int j = 0; j < physicalNumberOfRows; j++) {
                //获取每一行有多少单元格，遍历单元格
                HSSFRow  hssfRow = hssfSheet.getRow(j);
              HSSFRow  headerHssfRow = hssfSheet.getRow(0);
                physicalNumberOfCells = headerHssfRow.getPhysicalNumberOfCells();
                data = new ArrayList<>();
                for (int k = 0; k < physicalNumberOfCells; k++) {
                    HSSFCell cell = hssfRow.getCell(k);
                    if (cell != null) {
                        if (StringUtils.isBlank(cell.getStringCellValue())) {
                            cell.setCellType(CellType.STRING);
                        }
                        data.add(cell.getStringCellValue());
                    } else {
                        data.add("");
                    }
                }
                datas.add(data);
            }
        }
        wb.close();
        return datas;
    }

}
