package com.adc.da.util;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.web.multipart.MultipartFile;
import sun.misc.BASE64Decoder;
import sun.misc.BASE64Encoder;

import java.io.BufferedInputStream;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;

/**
 * 文件读取工具类
 */
public class FileUtil {
    private static final Logger logger = LoggerFactory.getLogger(FileUtil.class);

    private FileUtil() {
    }

    /**
     * 读取文件内容，作为字符串返回
     */
    public static String readFileAsString(String filePath) throws IOException {
        File file = new File(filePath);
        if (!file.exists()) {
            throw new FileNotFoundException(filePath);
        }

        if (file.length() > 1024 * 1024 * 1024) {
            throw new IOException("File is too large");
        }

        StringBuilder sb = new StringBuilder((int) (file.length()));
        try (FileInputStream fis = new FileInputStream(filePath)) {
            // 创建字节输入流

            // 创建一个长度为10240的Buffer
            byte[] bbuf = new byte[10240];
            // 用于保存实际读取的字节数
            int hasRead = 0;
            while ((hasRead = fis.read(bbuf)) > 0) {
                sb.append(new String(bbuf, 0, hasRead));
            }
            return sb.toString();
        }
    }

    /**
     * 根据文件路径读取byte[] 数组
     */
    public static byte[] readFileByBytes(String filePath) throws IOException {
        File file = new File(filePath);
        if (!file.exists()) {
            return null;
        } else {

            try (ByteArrayOutputStream bos = new ByteArrayOutputStream((int) file.length());
                 BufferedInputStream in = new BufferedInputStream(new FileInputStream(file))) {

                short bufSize = 1024;
                byte[] buffer = new byte[bufSize];
                int len1;
                while (-1 != (len1 = in.read(buffer, 0, bufSize))) {
                    bos.write(buffer, 0, len1);
                }

                return bos.toByteArray();
            }
        }
    }

    /**
     * 根据文件路径读取byte[] 数组
     */
    public static byte[] readFileByBytes(File file) throws IOException {
        if (!file.exists()) {
            throw new FileNotFoundException("");
        } else {

            try (ByteArrayOutputStream bos = new ByteArrayOutputStream((int) file.length());
                 BufferedInputStream in = new BufferedInputStream(new FileInputStream(file))) {

                short bufSize = 1024;
                byte[] buffer = new byte[bufSize];
                int len1;
                while (-1 != (len1 = in.read(buffer, 0, bufSize))) {
                    bos.write(buffer, 0, len1);
                }

                return bos.toByteArray();
            }
        }
    }
    /**
     * base64转MultipartFile
     *
     * @param base64
     * @return
     */
    public static MultipartFile base64ToMultipart(String base64) {
        try {
            String[] baseStrs = base64.split(",");

            BASE64Decoder decoder = new BASE64Decoder();
            byte[] b = decoder.decodeBuffer(baseStrs[1]);

            for (int i = 0; i < b.length; ++i) {
                if (b[i] < 0) {
                    b[i] += 256;
                }
            }

            return new BASE64DecodedMultipartFile(b, baseStrs[0]);
        } catch (IOException e) {
            logger.error("文件转换失败");
            return null;
        }
    }

    /**
     * 文件转base64
     *
     * @param path
     * @return
     */
    public static String encodeBase64File(String path) {
        File file = new File(path);
        try (FileInputStream inputFile = new FileInputStream(file)) {
            byte[] buffer = new byte[(int) file.length()];
            if (inputFile.read(buffer) > 0) {
                return new BASE64Encoder().encode(buffer);
            } else {
                return null;
            }
        } catch (Exception e) {
            logger.error("文件转换失败");
            return null;
        }
    }
}
