package com.adc.da.util;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.BufferedReader;
import java.io.DataOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.net.HttpURLConnection;
import java.net.URL;

/**
 * http 工具类
 */
public class HttpUtil {
    private static final Logger logger = LoggerFactory.getLogger(HttpUtil.class);

    /**
     * 发起post请求
     * @param requestUrl
     * @param accessToken
     * @param params
     * @return
     * @throws Exception
     */
    public static String post(String requestUrl, String accessToken, String params) {
        String contentType = "application/x-www-form-urlencoded";
        return HttpUtil.post(requestUrl, accessToken, contentType, params);
    }

    public static String post(String requestUrl, String accessToken, String contentType, String params) {
        String encoding = "UTF-8";
        if (requestUrl.contains("nlp")) {
            encoding = "GBK";
        }
        try {
            return HttpUtil.post(requestUrl, accessToken, contentType, params, encoding);
        } catch (IOException e) {
            logger.debug(e.getMessage());
            return "";
        }
    }

    /**
     * 发起post请求
     * @param requestUrl
     * @param accessToken
     * @param contentType
     * @param params
     * @param encoding
     * @return
     * @throws Exception
     */
    public static String post(String requestUrl, String accessToken, String contentType, String params, String encoding) throws IOException {
        String url = requestUrl + "?access_token=" + accessToken;
        return HttpUtil.postGeneralUrl(url, contentType, params, encoding);
    }

    /**
     * 发起post请求
     * @param generalUrl
     * @param contentType
     * @param params
     * @param encoding
     * @return
     * @throws Exception
     */
    public static String postGeneralUrl(String generalUrl, String contentType, String params, String encoding) throws IOException {
        URL url = new URL(generalUrl);
        // 打开和URL之间的连接
        HttpURLConnection connection = (HttpURLConnection) url.openConnection();
        connection.setRequestMethod("POST");
        // 设置通用的请求属性
        connection.setRequestProperty("Content-Type", contentType);
        connection.setRequestProperty("Connection", "Keep-Alive");
        connection.setUseCaches(false);
        connection.setDoOutput(true);
        connection.setDoInput(true);

        // 得到请求的输出流对象
        DataOutputStream out = new DataOutputStream(connection.getOutputStream());
        out.write(params.getBytes(encoding));
        out.flush();
        out.close();

        // 建立实际的连接
        connection.connect();
        // 获取所有响应头字段
//        Map<String, List<String>> headers = connection.getHeaderFields();
        // 遍历所有的响应头字段
        // 定义 BufferedReader输入流来读取URL的响应
        BufferedReader in = null;
        in = new BufferedReader(
                new InputStreamReader(connection.getInputStream(), encoding));
        String result = "";
        String getLine;
        while ((getLine = in.readLine()) != null) {
            result += getLine;
        }
        in.close();
        return result;
    }

    private HttpUtil() {
    }

    /**
     * http get请求
     *
     * @param httpUrl 链接
     * @return 响应数据
     */
    public static String doGet(String httpUrl) throws IOException {
        //链接
        HttpURLConnection connection = null;
        StringBuffer result = new StringBuffer();
        URL url = new URL(httpUrl);
        connection = (HttpURLConnection) url.openConnection();
        //设置请求方式
        connection.setRequestMethod("GET");
        //设置连接超时时间
        connection.setConnectTimeout(15000000);
        //设置读取超时时间
        connection.setReadTimeout(15000000);
        //开始连接
        connection.connect();
        if (connection.getResponseCode() == 200) {
            try (InputStream is = connection.getInputStream();
                 BufferedReader br = new BufferedReader(new InputStreamReader(is, "UTF-8"));) {
                String temp = null;
                while ((temp = br.readLine()) != null) {
                    result.append(temp);
                }
            }
        }
        return result.toString();
    }
}
